==> reactidsk-0.0.33.tgz: package/lib/components/MuiDatePicker/MuiTextField/MuiTextField.js <==
import React from 'react';
import { TextField, styled } from '@mui/material';
import { ErrorText } from '../../ErrorText/ErrorText';
import { HintText } from '../../HintText/HintText';
import { Label } from '../../Label/Label';
import { LabelText } from '../../LabelText/LabelText';
import { BLACK, RED, YELLOW } from '../../../global/colors';
const StyledTextField = styled(TextField)(({ fielderror }) => ({
    '& > div': {
        borderRadius: '0px',
        border: fielderror ? `4px solid ${RED}` : `2px solid ${BLACK}`,
        '&:focus-within': {
            outline: `3px solid ${YELLOW}`,
        },
        '& > input': {
            padding: '6.5px',
            height: '27px',
        },
        '& > fieldset': {
            display: 'none',
        },
        '& > div > button': {
            color: 'black',
        },
    },
}));
const MuiTextField = ({ meta, input, label, hint }) => {
    return (React.createElement(React.Fragment, null,
        React.createElement(Label, { error: (meta === null || meta === void 0 ? void 0 : meta.touched) && !!meta.error },
            React.createElement(LabelText, null, label),
            hint && React.createElement(HintText, null, hint),
            (meta === null || meta === void 0 ? void 0 : meta.touched) && meta.error && React.createElement(ErrorText, null, meta === null || meta === void 0 ? void 0 : meta.error),
            React.createElement(StyledTextField, Object.assign({}, input, { fielderror: meta === null || meta === void 0 ? void 0 : meta.error })))));
};
export default MuiTextField;

==> reactidsk-0.0.42.tgz: package/lib/components/MuiDatePicker/MuiTextField/MuiTextField.js <==
import React from 'react';
import { TextField, styled } from '@mui/material';
import { ErrorText } from '../../ErrorText/ErrorText';
import { HintText } from '../../HintText/HintText';
import { Label } from '../../Label/Label';
import { LabelText } from '../../LabelText/LabelText';
import { BLACK, RED, YELLOW } from '../../../global/colors';
const StyledTextField = styled(TextField)(({ meta }) => ({
    '& > div': {
        borderRadius: '0px',
        border: (meta === null || meta === void 0 ? void 0 : meta.error) && meta.touched ? `4px solid ${RED}` : `2px solid ${BLACK}`,
        '&:focus-within': {
            outline: `3px solid ${YELLOW}`,
        },
        '& > input': {
            padding: '6.5px',
            height: '27px',
        },
        '& > fieldset': {
            display: 'none',
        },
        '& > div > button': {
            color: 'black',
        },
    },
}));
const MuiTextField = ({ meta, input, label, hint }) => {
    return (React.createElement(React.Fragment, null,
        React.createElement(Label, { error: (meta === null || meta === void 0 ? void 0 : meta.touched) && !!meta.error },
            React.createElement(LabelText, null, label),
            hint && React.createElement(HintText, null, hint),
            (meta === null || meta === void 0 ? void 0 : meta.touched) && meta.error && React.createElement(ErrorText, null, meta === null || meta === void 0 ? void 0 : meta.error),
            React.createElement(StyledTextField, Object.assign({}, input, { meta: meta })))));
};
export default MuiTextField;
